---
name: Bug report
about: File a bug report
title: ''
labels: bug
assignees: oliver006

---

**Describe the problem**
A clear and concise description of what the bug is.


**Running the exporter**
What's the full command you're using to run the exporter? (please remove passwords and other sensitive data)

**Python version**
What Python version are you using?

**Expected behavior**
What metrics are missing? What metrics are wrong? Is something missing that was present in an earlier version?


**Screenshots**
If applicable, add screenshots to help explain your problem.


**Additional context**
Add any other context about the problem here.
